==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/fa.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "نام داده شده بیش از حد بلند است",
    "The given web address is too long" : "نشانی وب داده شده بیش از حد بلند است",
    "The given web address is not a valid URL" : "نشانی وب داده شده معتبر نیست",
    "The given legal notice address is too long" : "نشانی توصیهٔ حقوقی داده شده بیش از حد بلند است",
    "The given legal notice address is not a valid URL" : "نشانی توصیهٔ حقوقی داده شده معتبر نیست",
    "The given privacy policy address is too long" : "نشانی سیاست محرمانگی داده شده بیش از حد بلند است",
    "The given privacy policy address is not a valid URL" : "نشانی سیاست محرمانگی داده شده معتبر نیست",
    "The given slogan is too long" : "شعار داده شده بیش از حد بلند است",
    "The given color is invalid" : "رنگ داده شده نامعتبر است",
    "Disable-user-theming should be true or false" : "مقدار Disable-user-theming باید true یا false باشد",
    "Saved" : "ذخیره شد",
    "The file was uploaded" : "پرونده بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پروندهٔ بارگذاری شده بیش‌تر از upload_max_filesize در php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم پروندهٔ بارگذاری شده بیش‌تر از MAX_FILE_SIZE مشخّص شده در فرم HTML است",
    "The file was only partially uploaded" : "پرونده به صورت ناقص بارگذاری شده بود",
    "No file was uploaded" : "هیچ پرونده‌ای بارگذاری نشده",
    "Missing a temporary folder" : "یک شاخهٔ موقّتی گم شده",
    "Could not write file to disk" : "نتوانست پرونده را روی دیسک بنویسد",
    "A PHP extension stopped the file upload" : "یک افزونهٔ پی‌اچ‌پی بارگذاری پرونده را متوقّف کرد",
    "No file uploaded" : "هیچ پرونده‌ای بارگذاری نشد",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "هم‌اکنون در حال استفاده از یک زمینهٔ شخصی هستید. ممکن است تنظمیات کارهٔ زمینش به دستش پایکال شوند.",
    "Theming" : "زمینش",
    "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
    "Dark theme with high contrast mode" : "زمینهٔ تیره با حالت سایه‌روشن بالا",
    "Enable dark high contrast mode" : "به کار انداختن حالت سایه‌روشن تاریک",
    "Similar to the high contrast mode, but with dark colours." : "شبیه حالت سایه‌روشن بالا، ولی با رنگ‌های تیره",
    "Dark theme" : "زمینهٔ تیره",
    "Enable dark theme" : "به کار انداختن زمینهٔ تیره",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "زمینه‌ای تاریک برای آسایش چشمانتان با کاستن نوردهی و روشنایی کلّی.",
    "System default theme" : "زمینه ی پیش فرض سامانه",
    "Enable the system default" : "به کار انداختن پیش‌گزیدهٔ سامانه",
    "Using the default system appearance." : "استفاده از ظاهر پیش فرض سامانه",
    "Dyslexia font" : "قلم خوانش‌پریش",
    "Enable dyslexia font" : "به کار انداختن قلم خوانش‌پریش",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "اُپن‌دیسلکسیک قلمی آزاد است که برای کاهش برخی از خطاهای معمول در خواندن ناشی از خوانش‌پریشی طرّاحی شده.",
    "High contrast mode" : "حالت سایه‌روشن بالا",
    "Enable high contrast mode" : "به کار انداختن حالت سایه‌روشن بالا",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "حالتی با سایه‌روشن بالا برای آسایش ناوبریتان. کیفیت بصری کاهش خواهد یافت؛ ولی وضوح افزایش می‌باید.",
    "Light theme" : "زمینهٔ روشن",
    "Enable the default light theme" : "به کار انداختن زمینهٔ روشن پیش‌گزیده",
    "The default light appearance." : "ظاهر روشن پیش گزیده.",
    "Legal notice" : "توصیهٔ حقوقی",
    "Privacy policy" : "سیاست محرمانگی",
    "Adjust the Nextcloud theme" : "تنظیم زمینهٔ نکست‌کلود",
    "Name" : "نام",
    "Web link" : "پیوند وب",
    "a safe home for all your data" : "خانه‌ای امن برای تمامی داده‌هایتان",
    "Slogan" : "شعار",
    "Primary color" : "رنگ اصلی",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "رنگ اصلی برای برجسته‌سازی عناصر مانند دکمه‌های مهم استفاده می‌شود. این رنگ ممکن است با توجه به طرح رنگی فعلی کمی تغییر کند.",
    "Legal notice link" : "پیوند توصیهٔ حقوقی",
    "Privacy policy link" : "پیوند سیاست محرمانگی",
    "Header logo" : "نشان سرایند",
    "Upload new header logo" : "بارگذاری نشان سرایند جدید",
    "Favicon" : "نقشک صفحه",
    "Upload new favicon" : "بارگذاری نقشک صفحهٔ جدید",
    "User settings" : "تنظمبات کاربری",
    "Disable user theming" : "از کار انداختن زمینش کاربری",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users.",
    "Upload new logo" : "بارگذاری نشان جدید",
    "Logo" : "نشان",
    "Upload new background and login image" : "بارگذاری تصویر پس‌زمینه و ورود جدید",
    "Background and login image" : "تصویر پس‌زمینه و ورود",
    "Advanced options" : "گزینه‌های پیش‌رفته",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "اگر با هرگونه مشکلی مواجه شدید، در گزارش آن از طریق {issuetracker}سامانهٔ ردیابی مشکلات ما{linkend} دریغ نکنید. و اگر مایل به همکاری هستید، به {designteam}تیم طراحی ما{linkend} بپیوندید!",
    "Appearance and accessibility settings" : "تنظیمات ظاهر و دسترسی‌پذیری",
    "Misc accessibility options" : "گزینه‌های دسترسی‌پذیری متفرقه",
    "Enable blur background filter (may increase GPU load)" : "فیلتر محو کردن پس‌زمینه را فعال کنید (ممکن است بار پردازندهٔ گرافیکی را افزایش دهد)",
    "Customization has been disabled by your administrator" : "شخصی‌سازی به دست مدیر از کار افتاده است",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "یک رنگ اصلی برای برجسته‌سازی عناصر مهم تنظیم کنید. رنگی که برای عناصر مانند دکمه‌های اصلی استفاده می‌شود ممکن است کمی متفاوت باشد، زیرا برای برآورده کردن ملزومات دسترسی‌پذیری تنظیم می‌شود.",
    "Background and color" : "پس‌زمینه و رنگ",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "پس‌زمینه می‌تواند از میان عکس‌های مجموعهٔ پیش‌فرض، یک تصویر بارگذاری‌شدهٔ سفارشی، یا با یک رنگ ساده تنظیم شود.",
    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Disable all keyboard shortcuts" : "از کار انداختن تمامی میان‌برهای صفحه‌کلید",
    "Move up" : "حرکت به بالا",
    "Move down" : "حرکت به پایین",
    "Select a background from your files" : "تصویر پس‌زمینه را از میان پرونده‌هاتان انتخاب کنید",
    "Select background" : "انتخاب پس‌زمینه",
    "No background has been selected" : "پس‌زمینه‌ای انتخاب نشده است",
    "Custom background" : "پس‌زمینهٔ سفارشی",
    "Plain background" : "پس‌زمینهٔ ساده",
    "Default background" : "پس‌زمینهٔ پیش‌فرض",
    "Theme selection is enforced" : "گزینش زمینه اجباری است",
    "Could not set the app order" : "نتوانستیم ترتیب برنامه‌ها را تنظیم کنیم",
    "Navigation bar settings" : "تنظیمات نوار ناوبری",
    "Could not set primary color" : "نتوانستیم رنگ اصلی را تنظیم کنیم",
    "Reset primary color" : "تنظیم مجدد رنگ اصلی",
    "Select a custom color" : "گزینش رنگی شخصی",
    "Reset to default" : "بازنشانی به پیش‌گزیده",
    "Upload" : "بارگذاری",
    "Remove background image" : "برداشتن تصویر پس‌زمینه",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "دسترسی جهانی برای ما بسیار مهم است. ما از استانداردهای وب پیروی می‌کنیم و دقیت می‌کنیم تا همه چیز بدون موش‌واره و نرم‌افزارهای کمکی مانند صفحه‌خوان‌ها نیز قابل استفاده باشند. هدف ما این است که مطابق با دستورالعمل {guidelines}راهنماهای دسترس‌پذیری محتوا تحت وب{linkend} نسخه 2.1 در سطح AA، و حتی با زمینه کنتراست بالا در سطح AAA باشیم."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/fa.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "نام داده شده بیش از حد بلند است",
    "The given web address is too long" : "نشانی وب داده شده بیش از حد بلند است",
    "The given web address is not a valid URL" : "نشانی وب داده شده معتبر نیست",
    "The given legal notice address is too long" : "نشانی توصیهٔ حقوقی داده شده بیش از حد بلند است",
    "The given legal notice address is not a valid URL" : "نشانی توصیهٔ حقوقی داده شده معتبر نیست",
    "The given privacy policy address is too long" : "نشانی سیاست محرمانگی داده شده بیش از حد بلند است",
    "The given privacy policy address is not a valid URL" : "نشانی سیاست محرمانگی داده شده معتبر نیست",
    "The given slogan is too long" : "شعار داده شده بیش از حد بلند است",
    "The given color is invalid" : "رنگ داده شده نامعتبر است",
    "Saved" : "ذخیره شد",
    "The file was uploaded" : "پرونده بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پروندهٔ بارگذاری شده بیش‌تر از upload_max_filesize در php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم پروندهٔ بارگذاری شده بیش‌تر از MAX_FILE_SIZE مشخّص شده در فرم HTML است",
    "The file was only partially uploaded" : "پرونده به صورت ناقص بارگذاری شده بود",
    "No file was uploaded" : "هیچ پرونده‌ای بارگذاری نشده",
    "Missing a temporary folder" : "یک شاخهٔ موقّتی گم شده",
    "Could not write file to disk" : "نتوانست پرونده را روی دیسک بنویسد",
    "A PHP extension stopped the file upload" : "یک افزونهٔ پی‌اچ‌پی بارگذاری پرونده را متوقّف کرد",
    "No file uploaded" : "هیچ پرونده‌ای بارگذاری نشد",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "هم‌اکنون در حال استفاده از یک زمینهٔ شخصی هستید. ممکن است تنظمیات کارهٔ زمینش به دستش پایکال شوند.",
    "Theming" : "زمینش",
    "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
    "Dark theme with high contrast mode" : "زمینهٔ تیره با حالت سایه‌روشن بالا",
    "Enable dark high contrast mode" : "به کار انداختن حالت سایه‌روشن تاریک",
    "Similar to the high contrast mode, but with dark colours." : "شبیه حالت سایه‌روشن بالا، ولی با رنگ‌های تیره",
    "Dark theme" : "زمینهٔ تیره",
    "Enable dark theme" : "به کار انداختن زمینهٔ تیره",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "زمینه‌ای تاریک برای آسایش چشمانتان با کاستن نوردهی و روشنایی کلّی.",
    "System default theme" : "زمینه ی پیش فرض سامانه",
    "Enable the system default" : "به کار انداختن پیش‌گزیدهٔ سامانه",
    "Using the default system appearance." : "استفاده از ظاهر پیش فرض سامانه",
    "Dyslexia font" : "قلم خوانش‌پریش",
    "Enable dyslexia font" : "به کار انداختن قلم خوانش‌پریش",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "اُپن‌دیسلکسیک قلمی آزاد است که برای کاهش برخی از خطاهای معمول در خواندن ناشی از خوانش‌پریشی طرّاحی شده.",
    "High contrast mode" : "حالت سایه‌روشن بالا",
    "Enable high contrast mode" : "به کار انداختن حالت سایه‌روشن بالا",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "حالتی با سایه‌روشن بالا برای آسایش ناوبریتان. کیفیت بصری کاهش خواهد یافت؛ ولی وضوح افزایش می‌باید.",
    "Light theme" : "زمینهٔ روشن",
    "Enable the default light theme" : "به کار انداختن زمینهٔ روشن پیش‌گزیده",
    "The default light appearance." : "ظاهر روشن پیش گزیده.",
    "Legal notice" : "توصیهٔ حقوقی",
    "Privacy policy" : "سیاست محرمانگی",
    "Adjust the Nextcloud theme" : "تنظیم زمینهٔ نکست‌کلود",
    "Navigation bar settings" : "تنظیمات نوار ناوبری",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users.",
    "Name" : "نام",
    "Web link" : "پیوند وب",
    "Slogan" : "شعار",
    "a safe home for all your data" : "خانه‌ای امن برای تمامی داده‌هایتان",
    "Legal notice link" : "پیوند توصیهٔ حقوقی",
    "Privacy policy link" : "پیوند سیاست محرمانگی",
    "Background and color" : "پس‌زمینه و رنگ",
    "Primary color" : "رنگ اصلی",
    "Remove background image" : "برداشتن تصویر پس‌زمینه",
    "Favicon" : "نقشک صفحه",
    "Logo" : "نشان",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
    "Disable user theming" : "از کار انداختن زمینش کاربری",
    "Move up" : "حرکت به بالا",
    "Move down" : "حرکت به پایین",
    "Theme selection is enforced" : "گزینش زمینه اجباری است",
    "Could not set the app order" : "نتوانستیم ترتیب برنامه‌ها را تنظیم کنیم",
    "Select a background from your files" : "تصویر پس‌زمینه را از میان پرونده‌هاتان انتخاب کنید",
    "Select background" : "انتخاب پس‌زمینه",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "پس‌زمینه می‌تواند از میان عکس‌های مجموعهٔ پیش‌فرض، یک تصویر بارگذاری‌شدهٔ سفارشی، یا با یک رنگ ساده تنظیم شود.",
    "Custom background" : "پس‌زمینهٔ سفارشی",
    "Plain background" : "پس‌زمینهٔ ساده",
    "Default background" : "پس‌زمینهٔ پیش‌فرض",
    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Disable all keyboard shortcuts" : "از کار انداختن تمامی میان‌برهای صفحه‌کلید",
    "Could not set primary color" : "نتوانستیم رنگ اصلی را تنظیم کنیم",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "یک رنگ اصلی برای برجسته‌سازی عناصر مهم تنظیم کنید. رنگی که برای عناصر مانند دکمه‌های اصلی استفاده می‌شود ممکن است کمی متفاوت باشد، زیرا برای برآورده کردن ملزومات دسترسی‌پذیری تنظیم می‌شود.",
    "Reset primary color" : "تنظیم مجدد رنگ اصلی",
    "Reset to default" : "بازنشانی به پیش‌گزیده",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "اگر با هرگونه مشکلی مواجه شدید، در گزارش آن از طریق {issuetracker}سامانهٔ ردیابی مشکلات ما{linkend} دریغ نکنید. و اگر مایل به همکاری هستید، به {designteam}تیم طراحی ما{linkend} بپیوندید!",
    "Appearance and accessibility settings" : "تنظیمات ظاهر و دسترسی‌پذیری",
    "Misc accessibility options" : "گزینه‌های دسترسی‌پذیری متفرقه",
    "Enable blur background filter (may increase GPU load)" : "فیلتر محو کردن پس‌زمینه را فعال کنید (ممکن است بار پردازندهٔ گرافیکی را افزایش دهد)",
    "Customization has been disabled by your administrator" : "شخصی‌سازی به دست مدیر از کار افتاده است",
    "Disable-user-theming should be true or false" : "مقدار Disable-user-theming باید true یا false باشد",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "رنگ اصلی برای برجسته‌سازی عناصر مانند دکمه‌های مهم استفاده می‌شود. این رنگ ممکن است با توجه به طرح رنگی فعلی کمی تغییر کند.",
    "Header logo" : "نشان سرایند",
    "Upload new header logo" : "بارگذاری نشان سرایند جدید",
    "Upload new favicon" : "بارگذاری نقشک صفحهٔ جدید",
    "User settings" : "تنظمبات کاربری",
    "Upload new logo" : "بارگذاری نشان جدید",
    "Upload new background and login image" : "بارگذاری تصویر پس‌زمینه و ورود جدید",
    "Background and login image" : "تصویر پس‌زمینه و ورود",
    "Advanced options" : "گزینه‌های پیش‌رفته",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "دسترسی جهانی برای ما بسیار مهم است. ما از استانداردهای وب پیروی می‌کنیم و دقیت می‌کنیم تا همه چیز بدون موش‌واره و نرم‌افزارهای کمکی مانند صفحه‌خوان‌ها نیز قابل استفاده باشند. هدف ما این است که مطابق با دستورالعمل {guidelines}راهنماهای دسترس‌پذیری محتوا تحت وب{linkend} نسخه 2.1 در سطح AA، و حتی با زمینه کنتراست بالا در سطح AAA باشیم.",
    "No background has been selected" : "پس‌زمینه‌ای انتخاب نشده است",
    "Select a custom color" : "گزینش رنگی شخصی",
    "Upload" : "بارگذاری"
},
"nplurals=2; plural=(n > 1);");
